==> jsbos-workflow-2025.10.manager.dev-sources.jar: com/bringspring/workflow/engine/entity/FlowEngineTemplateEntity.java <==
package com.bringspring.workflow.engine.entity;


import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;

import java.util.Date;

/**
 * 流程引擎
 *
 * @author RKKJ开发平台组
 * @version V1.0.0
 * @copyright 荣科科技股份有限公司
 * @date 2024年8月7日 上午10:37
 */
@Data
@TableName("FLOW_ENGINE_TEMPLATE")
public class FlowEngineTemplateEntity {
    /**
     * 流程模板主键
     */
    @TableId("ID")
    private String id;

    /**
     * 流程引擎id
     */
    @TableField("FLOW_ID")
    private String flowId;

    /**
     * 流程编码
     */
    @TableField("ENCODE")
    private String enCode;

    @TableField("COMPANY_ID")
    private String companyId;

    /**
     * 流程名称
     */
    @TableField("FULL_NAME")
    private String fullName;

    /**
     * 可见类型 0-全部可见、1-指定经办
     */
    @TableField("VISIBLE_TYPE")
    private Integer visibleType;


    @TableField("VERSION")
    private String version;

//    /**
//     * 流程模板
//     */
//    @TableField(exist = false)
//    private String flowTemplateJson;

    /**
     * 版本号id
     */
    @TableField("VERSION_ID")
    private String versionId;

    /**
     * 排序码
     */
    @TableField("SORT_CODE")
    private Long sortCode;

    /**
     * 有效标志
     */
    @TableField("ENABLED_MARK")
    private Integer enabledMark;

    /**
     * 创建时间
     */
    @TableField(value = "CREATOR_TIME",fill = FieldFill.INSERT)
    private Date creatorTime;

    /**
     * 创建用户
     */
    @TableField(value = "CREATOR_USER_ID",fill = FieldFill.INSERT)
    private String creatorUserId;

    /**
     * 修改时间
     */
    @TableField(value = "LAST_MODIFY_TIME")
    private Date lastModifyTime;

    /**
     * 修改用户
     */
    @TableField(value = "LAST_MODIFY_USER_ID")
    private String lastModifyUserId;

    /**
     * 删除标志
     */
    @TableField("DELETE_MARK")
    private Integer deleteMark;

    /**
     * 删除时间
     */
    @TableField("DELETE_TIME")
    private Date deleteTime;

    /**
     * 删除用户
     */
    @TableField("DELETE_USER_ID")
    private String deleteUserId;

    @TableField(exist = false)
    private String type;


}

==> jsbos-workflow-2025.12.manager.dev-sources.jar: com/bringspring/workflow/engine/entity/FlowEngineTemplateEntity.java <==
package com.bringspring.workflow.engine.entity;


import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 流程引擎
 *
 * @author RKKJ开发平台组
 * @version V1.0.0
 * @copyright 荣科科技股份有限公司
 * @date 2024年8月7日 上午10:37
 */
@Data
@TableName("FLOW_ENGINE_TEMPLATE")
public class FlowEngineTemplateEntity {
    /**
     * 流程模板主键
     */
    @TableId("ID")
    private String id;

    /**
     * 流程引擎id
     */
    @TableField("FLOW_ID")
    private String flowId;

    /**
     * 流程编码
     */
    @TableField("ENCODE")
    private String enCode;

    @TableField("COMPANY_ID")
    private String companyId;

    /**
     * 流程名称
     */
    @TableField("FULL_NAME")
    private String fullName;

    /**
     * 可见类型 0-全部可见、1-指定经办
     */
    @TableField("VISIBLE_TYPE")
    private Integer visibleType;


    @TableField("VERSION")
    private String version;

//    /**
//     * 流程模板
//     */
//    @TableField(exist = false)
//    private String flowTemplateJson;

    /**
     * 版本号id
     */
    @TableField("VERSION_ID")
    private String versionId;

    /**
     * 排序码
     */
    @TableField("SORT_CODE")
    private Long sortCode;

    /**
     * 有效标志
     */
    @TableField("ENABLED_MARK")
    private Integer enabledMark;

    /**
     * 创建时间
     */
    @TableField(value = "CREATOR_TIME",fill = FieldFill.INSERT)
    private Date creatorTime;

    /**
     * 创建用户
     */
    @TableField(value = "CREATOR_USER_ID",fill = FieldFill.INSERT)
    private String creatorUserId;

    /**
     * 修改时间
     */
    @TableField(value = "LAST_MODIFY_TIME")
    private Date lastModifyTime;

    /**
     * 修改用户
     */
    @TableField(value = "LAST_MODIFY_USER_ID")
    private String lastModifyUserId;

    /**
     * 删除标志
     */
    @TableField("DELETE_MARK")
    private Integer deleteMark;

    /**
     * 删除时间
     */
    @TableField("DELETE_TIME")
    private Date deleteTime;

    /**
     * 删除用户
     */
    @TableField("DELETE_USER_ID")
    private String deleteUserId;

    @TableField(exist = false)
    private String type;

//    /**
//     * 流程使用频率
//     */
//    @TableField("USE_FREQUENCY")
//    private Integer useFrequency;
//
//    /**
//     * 平均审批时间
//     */
//    @TableField("AVERAGE_APPROVAL_TIME")
//    private Double averageApprovalTime;
//
//    /**
//     * 最长审批时间（节点）
//     */
//    @TableField("LONGEST_APPROVAL_NODE")
//    private String longestApprovalNode;
//
//    /**
//     * 审批停滞率
//     */
//    @TableField("APPROVAL_STOP_RATE")
//    private BigDecimal approvalStopRate;


}
